#[repr(C)]pub struct RaycastHitResult {
pub distance: Real,
pub normal: UnitVec3,
}Expand description
Result returned from Raycast::raycast
Contains information about a ray-shape intersection including the distance from the ray origin to the hit point and the surface normal at the hit location.
Fields
distance: RealDistance from the ray origin to the hit point
normal: UnitVec3Surface normal at the hit point (pointing outward from the shape)
Implementations